#!/usr/bin/env python
# -*- coding: utf-8 -*-

### BEGIN LICENSE
# Copyright © 2012-2018 Vsevolod Velichko <torkvema@gmail.com>
# Copyright © 2012 Carlos da Costa <c.costa@outlook.com>
# Copyright © 2012-2013 Erik Christiansson <erik@christiansson.net>
# Copyright © 2013 Pål Sollie <sollie@sparkz.no>
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

from . import TrackingService, unescape
import re
import json
from dateutil.parser import parse as parsedate


class CainiaoComService(TrackingService):
    """Cainiao, China"""

    name = "CainiaoCom"
    url = "http://global.cainiao.com/detail.htm?mailNoList=%(number)s&lang=en"

    def _parse_page(self, html):
        html = html.decode('utf-8', 'ignore')
        res = re.search(r'<textarea [^>]*id="waybill_list_val_box">([^<]+)</textarea>', html, re.DOTALL | re.UNICODE)
        if res is None:
            return []
        data = json.loads(unescape(res.group(1)))
        data = data['data'][0]['section2']['detailList']

        results = []
        for record in data:
            action = record['desc'].strip()
            date = record['time'] + ' UTC' + (record['timeZone'] or '')
            date = parsedate(date)
            results.append((action, date, ''))

        return results
