#!/usr/bin/env python
# -*- coding: utf-8 -*-

### BEGIN LICENSE
# Copyright © 2012-2018 Vsevolod Velichko <torkvema@gmail.com>
# Copyright © 2012 Carlos da Costa <c.costa@outlook.com>
# Copyright © 2012-2013 Erik Christiansson <erik@christiansson.net>
# Copyright © 2013 Pål Sollie <sollie@sparkz.no>
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

from . import TrackingService, unescape, untagify

import re
from dateutil.parser import parse as parsedate


class ColissimoFrService(TrackingService):
    """French post - Colissimo """

    name = "Colissimo.fr"
    url = 'http://www.laposte.fr/particulier/outils/en/track-a-parcel'
    post = 'suivi[number]=%(number)s'

    def _parse_page(self, html):
        html = html.decode('utf-8', 'ignore')
        res = re.search(r'<caption[^>]*>Results for.*?<tbody>(.*?)</table>', html, re.DOTALL | re.UNICODE)
        if res is None:
            return []
        html = res.group(1)

        result = []
        for date, action, location in re.findall(
            r'<tr[^>]*>\s*'
            r'<td[^>]*>\s*(.*?)\s*</td>\s*'
            r'<td[^>]*>\s*(.*?)\s*</td>\s*'
            r'<td[^>]*>\s*(.*?)\s*</td>\s*'
            r'</tr>',
            html,
            re.DOTALL | re.UNICODE
        ):
            date = untagify(unescape(date)).strip()
            action = untagify(unescape(action)).strip()
            location = untagify(unescape(location)).strip()
            result.append((action, parsedate(date, dayfirst=True), location))
        return result
