#!/usr/bin/env python
# -*- coding: utf-8 -*-

### BEGIN LICENSE
# Copyright © 2012-2018 Vsevolod Velichko <torkvema@gmail.com>
# Copyright © 2012 Carlos da Costa <c.costa@outlook.com>
# Copyright © 2012-2013 Erik Christiansson <erik@christiansson.net>
# Copyright © 2013 Pål Sollie <sollie@sparkz.no>
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

from . import TrackingService, untagify, unescape

import re
from dateutil.parser import parse as parsedate


class CorreiosComService(TrackingService):
    """ Brazilian postal service Correios - www.correios.com """

    name = "Correios"
    url = 'http://www2.correios.com.br/sistemas/rastreamento/resultado.cfm?'
    post = 'objetos=%(number)s&btnPesq=+Buscar'
    referer = 'http://www2.correios.com.br/sistemas/rastreamento/?ididioma=2'

    def _get_page(self):
        self._fetch_url('http://www2.correios.com.br/sistemas/rastreamento/?ididioma=2', None, {}, use_cookies=True)
        return super(CorreiosComService, self)._get_page()

    def _parse_page(self, html):
        html = html.decode('ISO-8859-1', 'ignore')
        res = re.search(r'<table class="listEvent sro">(.*?)</table>', html, re.DOTALL | re.IGNORECASE | re.UNICODE)
        if not res:
            return []
        html = res.group(1)

        res = re.findall(r'<tr[^>]*>\s*<td[^>]*>\s*(.*?)<br\s*/?>\s*(.*?)<br\s*/?>\s*(.*?)</td>\s*<td[^>]*>(.*?)</td>\s*</tr>',
                         html, re.DOTALL | re.IGNORECASE | re.UNICODE)

        result = []
        for (date, time, loc, action) in res:
            date = untagify(unescape(date)).replace(u'\n', u' ').strip()
            time = untagify(unescape(time)).replace(u'\n', u' ').strip()
            loc = untagify(unescape(loc)).replace(u'\n', u' ').strip()
            action = untagify(unescape(action)).replace(u'\n', u' ').strip()

            resdate = parsedate('%s %s' % (date, time), dayfirst=True)
            result.append((action, resdate, loc))
        return result
