# -*- coding: utf-8 -*-

### BEGIN LICENSE
# Copyright © 2012-2018 Vsevolod Velichko <torkvema@gmail.com>
# Copyright © 2012 Carlos da Costa <c.costa@outlook.com>
# Copyright © 2012-2013 Erik Christiansson <erik@christiansson.net>
# Copyright © 2013 Pål Sollie <sollie@sparkz.no>
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

from . import TrackingService

import re
from dateutil.parser import parse as parsedate


class SdaItService(TrackingService):
    """ SDA Italy"""

    name = "SDA Italy"
    url = 'http://www.sda.it/SITO_SDA-WEB/dispatcherHol?execute2=ActionTracking.doGetSpedizioneSelfTrck&LEN=ENG&id_cliente=000000000000&id_ldv=%(number)s'

    def _parse_page(self, html):
        html = html.decode('iso-8859-1', 'ignore')
        res = re.search(r"Tracking of the shipment.*?<td[^>]*>Date</td>\s*<td[^>]*>Status of the shipment</td>.*?</tr>(.*?)</table>", html, re.DOTALL | re.UNICODE)
        if res is None:
            return []
        html = res.group(1)
        result = []
        for date, action, location in re.findall(r'<tr>.*?<td[^>]*>(.*?)</td>\s*<td[^>]*>(.*?)</td>\s*<td[^>]*>(.*?)</td>', html, re.DOTALL | re.UNICODE):
            result.append((action.strip(), parsedate(date.strip(), dayfirst=True), location.strip()))

        return result
