#!/usr/bin/env python
# -*- coding: utf-8 -*-

### BEGIN LICENSE
# Copyright © 2012-2018 Vsevolod Velichko <torkvema@gmail.com>
# Copyright © 2012 Carlos da Costa <c.costa@outlook.com>
# Copyright © 2012-2013 Erik Christiansson <erik@christiansson.net>
# Copyright © 2013 Pål Sollie <sollie@sparkz.no>
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

from . import TrackingService, unescape

import re
from dateutil.parser import parse as parsedate


class UpsComService(TrackingService):
    """ UPS """

    name = "UPS"
    url = 'https://wwwapps.ups.com/WebTracking/track'
    post = 'loc=en_US&HTMLVersion=5.0U&SER_HISTORY_LIST=&trackNums=%(number)s&track.x=Track'

    def _get_page(self):
        self._fetch_url('https://www.ups.com/?Site=Corporate&cookie=us_en_home&setCookie=yes', None, {}, True)
        self._fetch_url('https://wwwapps.ups.com/WebTracking/track', None, {})
        return super(UpsComService, self)._get_page()

    def _parse_page(self, html):
        html = html.decode('utf-8', 'ignore')
        res = re.search('<div id="collapse3".*?<table[^>]*>(.*?)</table>', html, re.DOTALL)
        if res is None:
            return []
        html = res.group(1)
        result = []
        for res in re.findall('<tr[^>]*>\s*<td[^>]*>(.*?)</td>\s*<td[^>]*>(.*?)</td>\s*<td[^>]*>(.*?)</td>\s*<td[^>]*>([^<]*)</', html, re.DOTALL):
            location, opdate, optime, action = (re.sub('\s+', ' ', x, re.UNICODE).strip() for x in res)
            optime = unescape(optime.replace('.M.', 'M'))  # A.M. -> AM
            opdate = parsedate('%s %s' % (unescape(opdate).strip(), optime.strip()), fuzzy_with_tokens=True)[0]
            action = re.sub('\s+', ' ', unescape(action)).strip()
            location = re.sub('\s+', ' ', unescape(location)).strip()
            result.append((action, opdate, location))
        return result
